@@ -26,11 +26,22 @@ TEMPLATE_PHJOB_FILE_R = "/template/python/phcli/maxauto/phjob-r-20210122.tmp"
 TEMPLATE_PHMAIN_FILE_PY = "/template/python/phcli/maxauto/phmain-20210104.tmp"
 TEMPLATE_PHMAIN_FILE_R = "/template/python/phcli/maxauto/phmain-r-20210122.tmp"
 
-TEMPLATE_JUPYTER_PYTHON_FILE = '/template/python/phcli/maxauto/phJupyterPython-20210122.json'
+TEMPLATE_JUPYTER_PYTHON_FILE = '/template/python/phcli/maxauto/phJupyterPython-20210322.json'
 TEMPLATE_JUPYTER_R_FILE = '/template/python/phcli/maxauto/phJupyterR-20210122.json'
 
 TEMPLATE_PHDAG_FILE = "/template/python/phcli/maxauto/phdag-20210104.yaml"
 TEMPLATE_PHGRAPHTEMP_FILE = "/template/python/phcli/maxauto/phgraphtemp-20210104.tmp"
-TEMPLATE_PHDAGJOB_FILE = "/template/python/phcli/maxauto/phDagJob-20210129.tmp"
+TEMPLATE_PHDAGJOB_FILE = "/template/python/phcli/maxauto/phDagJob-20210325.tmp"
 
-PRESET_MUST_ARGS = 'owner, run_id, job_id'
+DEFAULT_RESULT_PATH_FORMAT_STR = "s3a://{bucket_name}/{version}/{dag_name}/"
+DEFAULT_RESULT_PATH_BUCKET = "ph-max-auto"
+DEFAULT_RESULT_PATH_VERSION = "2020-08-11"
+DEFAULT_RESULT_PATH_SUFFIX = "refactor/runs"
+DEFAULT_ASSET_PATH_FORMAT_STR = "s3a://{bucket_name}/{version}/"
+DEFAULT_ASSET_PATH_BUCKET = 'ph-max-auto'
+DEFAULT_ASSET_PATH_VERSION = "2020-08-11"
+DEFAULT_ASSET_PATH_SUFFIX = "asset"
+
+
+
+PRESET_MUST_ARGS = 'owner, dag_name, run_id, job_full_name, job_id'
